containertools.reverse_contents_of_container
============================================

.. autofunction:: abjad.tools.containertools.reverse_contents_of_container.reverse_contents_of_container
   :noindex:
